@@ -32,32 +32,32 @@ copyright holder.
 
 import re
 from dcop    import DCOPClient
-from qt      import QString, QCString, QByteArray, QDataStream, IO_ReadOnly, IO_WriteOnly
-from kdecore import dcop_add, dcop_next
+from python_tqt.qt import TQString, TQCString, TQByteArray, TQDataStream, IO_ReadOnly, IO_WriteOnly
+from tdecore import dcop_add, dcop_next
 
 # XXX: 64 bit integers might be handeld wrong! pythons int is AFAIK 32 bit,
 #      but pythons long is a arbitrary-precision integer. how to handle that?
 #
 #      I think 64 bit types would be:
 #      long long, unsigned long long, long long int, unsigned long long int,
-#      Q_LLONG, Q_ULLONG, Q_INT64, Q_UINT64
+#      TQ_LLONG, TQ_ULLONG, TQ_INT64, TQ_UINT64
 #
 #      and on some (most?) systems:
-#      QtOffset
+#      TQtOffset
 
 # add complex? complex is c99, not c++
 # but python has a complex type
 POD               = set(['char','short','int','long','float','double'])
 typedefIntTypes   = set(["uchar", "ushort", "uint", "ulong",
-                         "Q_INT8", "Q_INT16", "Q_INT32", "Q_LONG",
-                         "Q_UINT8", "Q_UINT16", "Q_UINT32", "Q_ULONG",
+                         "TQ_INT8", "Q_INT16", "TQ_INT32", "TQ_LONG",
+                         "TQ_UINT8", "Q_UINT16", "TQ_UINT32", "Q_ULONG",
                          "sitze_t", "ssize_t", "int8_t", "int16_t", "int32_t",
 			 "uint8_t", "uint16_t", "uint32_t", "pid_t", "uid_t",
 			 "off_t"])
 # XXX string and std::string too?
-stringTypes       = set(["QString", "QCString"])
-pythonStringTypes = set([QString, QCString, str])
-stringTypesDict   = {"QString":QString,"QCString":QCString,"str":str,"unicode":unicode}
+stringTypes       = set(["TQString", "TQCString"])
+pythonStringTypes = set([TQString, TQCString, str])
+stringTypesDict   = {"TQString":TQString,"TQCString":TQCString,"str":str,"unicode":unicode}
 
 VOID    = 0
 BOOLEAN = 1 # XXX bool is not supported by dcop_add, but maybe some time...
@@ -76,7 +76,7 @@ allow transparent Python calls to DCOP methods. For example:
 	d = DCOPApp ("kicker", dcop)
 
 (where "kicker" is the complete name of an application and 'dcop' is
-the dcopClient instance owned by the KApplication creating the DCOPApp
+the dcopClient instance owned by the TDEApplication creating the DCOPApp
 instance) creates a DCOPApp instance. All of the classes in this
 file "borrow" a DCOPClient instance from the calling application.
 
@@ -120,7 +120,7 @@ value the call returns. In this case, panelSize takes no arguments and
 returns an int. 'ok' returns the status of the DCOP call (success = True,
 failure = False).
 
-	ok = d.Panel.addURLButton (QString ("http://www.kde.org"))
+	ok = d.Panel.addURLButton (TQString ("http://www.kde.org"))
 
 would call addURLButton with the required argument, and return nothing but the DCOP call
 status(since its return type is 'void').
@@ -667,11 +667,11 @@ class DCOPMeth(object):
 		return has
 
 	def __marshall(self, args, argtypes):
-		data = QByteArray()
+		data = TQByteArray()
 		if argtypes == []:
 			return data
 
-		params = QDataStream (data, IO_WriteOnly)
+		params = TQDataStream (data, IO_WriteOnly)
 
 		for arg, (argtype, argkind) in _xiter(args, argtypes):
 			if argkind == BOOLEAN:
@@ -688,12 +688,12 @@ class DCOPMeth(object):
 
 				dcop_add(params, arg)
 
-			elif argtype.startswith("QMap") or argtype.startswith("QValueList"):
+			elif argtype.startswith("TQMap") or argtype.startswith("TQValueList"):
 				dcop_add(params, arg, argtype)
 
 			# XXX:
 			# Is 'isinstance(arg, eval(argtype))' really good?
-			# What if 'argtype' is located in some modul? Like 'qt.QString'.
+			# What if 'argtype' is located in some modul? Like 'qt.TQString'.
 			# Then this will fail (but it should not!).
 			# And the worst thing: the eval() will raise a NameError!
 			#
@@ -715,7 +715,7 @@ class DCOPMeth(object):
 		return data
 
 	def __unmarshall(self, data, type_):
-		s = QDataStream(data, IO_ReadOnly)
+		s = TQDataStream(data, IO_ReadOnly)
 
 		if str(type_) in stringTypes:
 			return unicode(dcop_next(s, type_))
